//system.c
#include "system.h"
#include <iolpc2148.h>
#include "bits.h"

// System initialization
void SysInit(void) {

  // PINSEL configuration
  PINSEL0 = 0x00000000;
  PINSEL1 = 0x00000000;
  PINSEL2 = 0x00000004;


  // Leds as high - turn off
  IO0SET |= (BIT10|BIT11);

  // Init leds port - as output
  IO0DIR |= (BIT10|BIT11);


  // Button as input
  IO0DIR &= ~(BIT15);

  // VPB Divider determines the relationship between the processor clock (cclk)
  // and the clock used by peripheral devices (pclk).
  // cclk:pclk = 1:1
  // VPBDIV = 0x11;

  // Initialization of MAM (Memory Accelerator Module)
  // MAM functions disabled
  MAMCR_bit.MODECTRL = 0;
  // MAM fetch cycles are 4 processor clocks (cclks) in duration
  MAMTIM_bit.CYCLES = 4;
  // MAM functions partially enabled.
  MAMCR_bit.MODECTRL = 1;


  //MEMMAP
  // 00: Boot Loader Mode. Interrupt vectors are re-mapped to Boot Block.
  // 01: User Flash Mode. Interrupt vectors are not re-mapped and reside in Flash.
  // 10: User RAM Mode. Interrupt vectors are re-mapped to Static RAM.
  // 11: User External memory Mode. Interrupt vectors are re-mapped to external memory.
  MEMMAP = 1;

}


// Init frequency
void FreqInit(void) {

  //crystal is 14 745 600
  //devide or multiplier
  //here is calculate frecuence
  PLLCFG_bit.MSEL = 0x2;  //M - multiplier -> 3
  PLLCFG_bit.PSEL = 0x1;  //P - devider ->2

  //set changes (require from architecture)
  PLLFEED_bit.FEED = 0xAA;
  PLLFEED_bit.FEED = 0x55;

  //enable or connect PLL
  //enable PLL
  PLLCON_bit.PLLE = 1;
  //set changes (require from architecture)
  PLLFEED_bit.FEED = 0xAA;
  PLLFEED_bit.FEED = 0x55;

  //wait for PLOK (correct freq)
  while(PLLSTAT_bit.PLOCK == 0);

  //connect PLL
  PLLCON_bit.PLLC = 1;
  //set changes (require from architecture)
  PLLFEED_bit.FEED = 0xAA;
  PLLFEED_bit.FEED = 0x55;

}



